@@ -31,12 +31,14 @@ class Document(object):
         self.namespace = {}
 
     @classmethod
-    def parse(cls, path, *parsers):
+    def parse(cls, path, *parsers, **kw):
         """
         Read the text from the supplied path and parse it into a document
         using the supplied parsers.
         """
-        with open(path) as source:
+        # python 2 compat:
+        encoding = kw.pop('encoding', 'utf-8')
+        with open(path, encoding=encoding) as source:
             text = source.read()
         document = cls(text, path)
         for parser in parsers:
